aboutsummaryrefslogtreecommitdiffstats
path: root/eclipse
diff options
context:
space:
mode:
authorTor Norbye <tnorbye@google.com>2012-03-21 11:22:18 -0700
committerAndroid (Google) Code Review <android-gerrit@google.com>2012-03-21 11:22:18 -0700
commit68211310bfe60be51962bb5e7db692c51a48b81e (patch)
treeb2e63c479cddaaeb99d62a69325409808ec23d4f /eclipse
parent90d46ad18662d418d0a9cd85afe854e73d884c9c (diff)
parent253bfc9e4a7b3a0ffd42c7a364763e16db66edb2 (diff)
downloadsdk-68211310bfe60be51962bb5e7db692c51a48b81e.zip
sdk-68211310bfe60be51962bb5e7db692c51a48b81e.tar.gz
sdk-68211310bfe60be51962bb5e7db692c51a48b81e.tar.bz2
Merge "Add plain XML editor for typeless XML files"
Diffstat (limited to 'eclipse')
-rwxr-xr-xeclipse/plugins/com.android.ide.eclipse.adt/src/com/android/ide/eclipse/adt/internal/editors/common/CommonXmlEditor.java9
-rw-r--r--eclipse/plugins/com.android.ide.eclipse.adt/src/com/android/ide/eclipse/adt/internal/editors/otherxml/PlainXmlEditorDelegate.java50
2 files changed, 55 insertions, 4 deletions
diff --git a/eclipse/plugins/com.android.ide.eclipse.adt/src/com/android/ide/eclipse/adt/internal/editors/otherxml/PlainXmlEditorDelegate.java b/eclipse/plugins/com.android.ide.eclipse.adt/src/com/android/ide/eclipse/adt/internal/editors/otherxml/PlainXmlEditorDelegate.java
new file mode 100644
index 0000000..5366988
--- /dev/null
+++ b/eclipse/plugins/com.android.ide.eclipse.adt/src/com/android/ide/eclipse/adt/internal/editors/otherxml/PlainXmlEditorDelegate.java
@@ -0,0 +1,50 @@
+/*
+ * Copyright (C) 2012 The Android Open Source Project
+ *
+ * Licensed under the Eclipse Public License, Version 1.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.eclipse.org/org/documents/epl-v10.php
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package com.android.ide.eclipse.adt.internal.editors.otherxml;
+
+import com.android.ide.eclipse.adt.internal.editors.common.CommonXmlDelegate;
+import com.android.ide.eclipse.adt.internal.editors.common.CommonXmlEditor;
+
+import org.w3c.dom.Document;
+
+/**
+ * Plain XML editor with no form for files that have no associated descriptor data
+ */
+public class PlainXmlEditorDelegate extends CommonXmlDelegate {
+
+ /**
+ * Creates the form editor for plain XML files.
+ */
+ public PlainXmlEditorDelegate(CommonXmlEditor editor) {
+ super(editor, new OtherXmlContentAssist());
+ editor.addDefaultTargetListener();
+ }
+
+ // ---- Base Class Overrides ----
+
+ @Override
+ public void delegateCreateFormPages() {
+ }
+
+ @Override
+ public void delegateXmlModelChanged(Document xml_doc) {
+ }
+
+ @Override
+ public void delegateInitUiRootNode(boolean force) {
+ }
+}
diff --git a/eclipse/plugins/com.android.ide.eclipse.adt/src/com/android/ide/eclipse/adt/internal/editors/common/CommonXmlEditor.java b/eclipse/plugins/com.android.ide.eclipse.adt/src/com/android/ide/eclipse/adt/internal/editors/common/CommonXmlEditor.java
index 68c7807..5ee76c2 100755
--- a/eclipse/plugins/com.android.ide.eclipse.adt/src/com/android/ide/eclipse/adt/internal/editors/common/CommonXmlEditor.java
+++ b/eclipse/plugins/com.android.ide.eclipse.adt/src/com/android/ide/eclipse/adt/internal/editors/common/CommonXmlEditor.java
@@ -28,6 +28,7 @@ import com.android.ide.eclipse.adt.internal.editors.drawable.DrawableEditorDeleg
import com.android.ide.eclipse.adt.internal.editors.layout.LayoutEditorDelegate;
import com.android.ide.eclipse.adt.internal.editors.menu.MenuEditorDelegate;
import com.android.ide.eclipse.adt.internal.editors.otherxml.OtherXmlEditorDelegate;
+import com.android.ide.eclipse.adt.internal.editors.otherxml.PlainXmlEditorDelegate;
import com.android.ide.eclipse.adt.internal.editors.uimodel.UiElementNode;
import com.android.ide.eclipse.adt.internal.editors.values.ValuesEditorDelegate;
import com.android.ide.eclipse.adt.internal.resources.manager.ResourceManager;
@@ -155,13 +156,13 @@ public class CommonXmlEditor extends AndroidXmlEditor implements IShowEditorInpu
if (mDelegate == null) {
// We didn't find any editor.
// We'll use the OtherXmlEditorDelegate as a catch-all editor.
AdtPlugin.log(IStatus.INFO,
"No valid Android XML Editor Delegate found for file %1$s [Res %2$s, type %3$s]",
file.getFullPath(),
resFolder,
type);
- mDelegate = new OtherXmlEditorDelegate(this);
+ mDelegate = new PlainXmlEditorDelegate(this);
}
} else if (editorInput instanceof IURIEditorInput) {
String folderName = AdtUtils.getParentFolderName(editorInput);
@@ -182,13 +183,13 @@ public class CommonXmlEditor extends AndroidXmlEditor implements IShowEditorInpu
if (mDelegate == null) {
// We didn't find any editor.
// We'll use the OtherXmlEditorDelegate as a catch-all editor.
AdtPlugin.log(IStatus.INFO,
"No valid Android XML Editor Delegate found for file %1$s [Res %2$s, type %3$s]",
((IURIEditorInput) editorInput).getURI().toString(),
folderName,
type);
- mDelegate = new OtherXmlEditorDelegate(this);
+ mDelegate = new PlainXmlEditorDelegate(this);
}
}
@@ -155,13 +156,13 @@ public class CommonXmlEditor extends AndroidXmlEditor implements IShowEditorInpu
if (mDelegate == null) {
// We didn't find any editor.
- // We'll use the OtherXmlEditorDelegate as a catch-all editor.
+ // We'll use the PlainXmlEditorDelegate as a catch-all editor.
AdtPlugin.log(IStatus.INFO,
"No valid Android XML Editor Delegate found for file %1$s [Res %2$s, type %3$s]",
@@ -182,13 +183,13 @@ public class CommonXmlEditor extends AndroidXmlEditor implements IShowEditorInpu
if (mDelegate == null) {
// We didn't find any editor.
- // We'll use the OtherXmlEditorDelegate as a catch-all editor.
+ // We'll use the PlainXmlEditorDelegate as a catch-all editor.
AdtPlugin.log(IStatus.INFO,
"No valid Android XML Editor Delegate found for file %1$s [Res %2$s, type %3$s]",